@@ -34,6 +34,8 @@
 #include <sys/time.h>
 #include <sys/wait.h>
 #include <unistd.h>
+#include "types.h"
+#include "pmain.h"
 
 static char *_cfConfigDir;
 static char *_cfDataDir;
@@ -183,7 +185,11 @@ static void reset(void)
 	}
 }
 
+#if defined(__linux)
 static void dumpcontext(int signal, struct sigcontext r)
+#else
+static void dumpcontext(int signal)
+#endif
 {
 	if (signal==SIGSEGV)
 		fprintf(stderr, "Segmentation Fault\n");
@@ -209,7 +215,11 @@ static void dumpcontext(int signal, struct sigcontext r)
 #endif /* we should have an else here for BSD */
 }
 
+#if defined(__linux)
 void sigsegv(int signal, struct sigcontext r)
+#else
+void sigsegv(int signal)
+#endif
 {
 #ifdef KICKSTART_GDB
 	char *argv[5];
@@ -228,8 +238,11 @@ void sigsegv(int signal, struct sigcontext r)
 
 	if (*_plSetTextMode) /* don't reset if we havn't used the screen yet */
 		reset();
-	
+#if defined(__linux)
 	dumpcontext(signal, r);
+#else
+	dumpcontext(signal);
+#endif
 
 #ifdef KICKSTART_GDB
 	/* first hook up stderr if is not */
@@ -252,7 +265,8 @@ void sigsegv(int signal, struct sigcontext r)
 			}
 			setsid();
 
-			chdir(dir);
+			if (dir)
+				chdir(dir);
 			execvp("gdb", argv);
 
 			perror("execvp(gdb)\n");
@@ -449,12 +463,12 @@ static char *locate_libocp(void)
 
 static int runocp(void *handle, int argc, char *argv[])
 {
-	int (*bootup)(int argc, char *argv[]);
+	struct mainstruct *bootup;
 	char *cfConfigDir;
 	char *cfDataDir;
 	char *cfProgramDir;
 
-	if (!(*((void **)&bootup)=dlsym(handle, "bootup")))
+	if (!(bootup=dlsym(handle, "bootup")))
 	{
 		fprintf(stderr, "Failed to locate symbol bootup in libocp" LIB_SUFFIX ": %s\n", dlerror());
 		return -1;
@@ -501,7 +515,7 @@ static int runocp(void *handle, int argc, char *argv[])
 	free(_cfConfigDir);
 	free(_cfProgramDir);
 
-	return bootup(argc, argv);
+	return bootup->main(argc, argv);
 }
 
 int main(int argc, char *argv[])
@@ -520,11 +534,11 @@ int main(int argc, char *argv[])
 	signal(SIGBUS, (sighandler_t)sigsegv);
 	signal(SIGINT, (sighandler_t)sigsegv);
 #else
-	signal(SIGSEGV, (void (*)(int))sigsegv);
-	signal(SIGFPE, (void (*)(int))sigsegv);
-	signal(SIGILL, (void (*)(int))sigsegv);
-	signal(SIGBUS, (void (*)(int))sigsegv);
-	signal(SIGINT, (void (*)(int))sigsegv);
+	signal(SIGSEGV, sigsegv);
+	signal(SIGFPE, sigsegv);
+	signal(SIGILL, sigsegv);
+	signal(SIGBUS, sigsegv);
+	signal(SIGINT, sigsegv);
 #endif
 
 	argv0=argv[0];
@@ -553,6 +567,10 @@ int main(int argc, char *argv[])
 
 	retval = runocp(handle, argc, argv);
 
+	free(dir);
+
+	dir=0;
+
 #ifdef HAVE_DUMA
 	DUMA_delFrame();
 #endif
