@@ -209,10 +209,8 @@ void lnkFree(const int id)
 	{
 		for (i=loadlist_n-1;i>=0;i--)
 		{
-#ifndef HAVE_DUMA
-#ifndef HAVE_EFENCE
+#ifndef NO_DLCLOSE
 			dlclose(loadlist[i].handle);
-#endif
 #endif
 		}
 		loadlist_n=0;
@@ -220,10 +218,8 @@ void lnkFree(const int id)
 		for (i=loadlist_n-1;i>=0;i--)
 			if (loadlist[i].id==id)
 			{
-#ifndef HAVE_DUMA
-#ifndef HAVE_EFENCE
+#ifndef NO_DLCLOSE
 				dlclose(loadlist[i].handle);
-#endif
 #endif
 				memmove(&loadlist[i], &loadlist[i+1], (MAXDLLLIST-i-1)*sizeof(loadlist[0]));
 				loadlist_n--;
