@@ -8,4 +8,9 @@ struct initcloseregstruct
 	struct initcloseregstruct *next;
 };
 
+struct mainstruct
+{
+	int (*main)(int argc, char *argv[]);
+};
+
 #endif
