@@ -26,27 +26,27 @@
 #include "boot/psetting.h"
 #include <curses.h>
 
-static unsigned char (*plWuerfel)=NULL;
-char plWuerfelDirect;
-static char wuerfelpal[720];
-static short wuerfelpos;
-unsigned long wuerfeltnext;
-static unsigned long wuerfelscroll;
-static unsigned short wuerfelstframes;
-static unsigned short wuerfelframes;
-static unsigned short wuerfelrle;
-static unsigned short wuerfeldlt;
-static unsigned char wuerfellowmem;
-static unsigned char *wuerfelloadedframes;
-static unsigned short *wuerfelframelens;
-static unsigned long *wuerfelframepos;
-static unsigned short *wuerfelcodelens;
-static unsigned long wuerfelframe0pos;
-static unsigned long wuerfelframesize;
-static unsigned long wuerfelscanlines, wuerfellinelength, wuerfelversion;
-static short wuerfelfile;
-static unsigned char *wuerfelframebuf;
-static unsigned long cfUseAnis=0xFFFFFFFF;
+static unsigned char *plWuerfel=NULL;
+static int plWuerfelDirect;
+static uint8_t wuerfelpal[720];
+static uint16_t wuerfelpos;
+static uint32_t wuerfeltnext;
+static uint32_t wuerfelscroll;
+static uint16_t wuerfelstframes;
+static uint16_t wuerfelframes;
+static uint16_t wuerfelrle;
+static uint16_t wuerfeldlt;
+static uint8_t wuerfellowmem;
+static uint8_t *wuerfelloadedframes;
+static uint16_t *wuerfelframelens;
+static uint32_t *wuerfelframepos;
+static uint16_t *wuerfelcodelens;
+static uint32_t wuerfelframe0pos;
+static uint32_t wuerfelframesize;
+static uint32_t wuerfelscanlines, wuerfellinelength, wuerfelversion;
+static int wuerfelfile;
+static uint8_t *wuerfelframebuf;
+static uint32_t cfUseAnis=0xFFFFFFFF;
 
 static void memcpyintr(char *d, const char *s, unsigned long l)
 {
@@ -93,11 +93,11 @@ static int plCloseWuerfel(void)
 static char plLoadWuerfel(void)
 {
 	int ifile;
-	unsigned char sig[8];
-	unsigned short opt, pallen, codelenslen;
-	short i;
-	unsigned short maxframe;
-	unsigned long framemem;
+	uint8_t sig[8];
+	uint16_t opt, pallen, codelenslen;
+	int i;
+	uint16_t maxframe;
+	uint32_t framemem;
 
 	if (plWuerfel)
 		plCloseWuerfel();
@@ -106,7 +106,7 @@ static char plLoadWuerfel(void)
 
 	while (cfUseAnis)
 	{
-		unsigned char use=rand()&31;
+		int use=rand()&31;
 		char path[PATH_MAX+1];
 
 		if (!(cfUseAnis&(1<<use)))
@@ -142,9 +142,12 @@ static char plLoadWuerfel(void)
 	lseek(ifile, 32, SEEK_CUR);
 
 	read(ifile, &wuerfelframes, 2);
+	wuerfelframes=uint16_little(wuerfelframes);
 	read(ifile, &wuerfelstframes, 2);
+	wuerfelstframes=uint16_little(wuerfelstframes);
 
 	read(ifile, &opt, 2);
+	opt=uint16_little(opt);
 	wuerfelrle=opt&1;
 	wuerfeldlt=!!(opt&2);
 	wuerfelframesize=(opt&4)?64000:16000;
@@ -152,10 +155,10 @@ static char plLoadWuerfel(void)
 	wuerfellinelength=(opt&4)?320:160;
 	wuerfelversion=!!(opt&4);
 
-	wuerfelframelens=calloc(sizeof(unsigned short), wuerfelframes+wuerfelstframes);
-	wuerfelframepos=calloc(sizeof(unsigned long), wuerfelframes+wuerfelstframes);
-	wuerfelframebuf=calloc(sizeof(unsigned char), wuerfelframesize);
-	wuerfelloadedframes=calloc(sizeof(unsigned char), wuerfelframes+wuerfelstframes);
+	wuerfelframelens=calloc(sizeof(uint16_t), wuerfelframes+wuerfelstframes);
+	wuerfelframepos=calloc(sizeof(uint32_t), wuerfelframes+wuerfelstframes);
+	wuerfelframebuf=calloc(sizeof(uint8_t), wuerfelframesize);
+	wuerfelloadedframes=calloc(sizeof(uint8_t), wuerfelframes+wuerfelstframes);
 
 	if (!wuerfelframelens||!wuerfelframepos||!wuerfelframebuf||!wuerfelloadedframes)
 	{
@@ -165,13 +168,15 @@ static char plLoadWuerfel(void)
 
 	lseek(ifile, 2, SEEK_CUR);
 	read(ifile, &codelenslen, 2);
-	wuerfelcodelens=calloc(sizeof(unsigned short), codelenslen);
+	codelenslen=uint16_little(codelenslen);
+	wuerfelcodelens=calloc(sizeof(uint16_t), codelenslen);
 	if (!wuerfelcodelens)
 	{
 		plCloseWuerfel();
 		return 0;
 	}
 	read(ifile, &pallen, 2);
+	pallen=uint16_little(pallen);
 	read(ifile, wuerfelframelens, 2*(wuerfelframes+wuerfelstframes));
 
 	if(wuerfelversion)
@@ -196,7 +201,7 @@ static char plLoadWuerfel(void)
 
 	framemem=wuerfelframepos[i-1]+wuerfelframelens[i-1];
 
-	plWuerfel=calloc(sizeof(unsigned char),  framemem);
+	plWuerfel=calloc(sizeof(uint8_t),  framemem);
 
 	wuerfelframe0pos=lseek(ifile, 0, SEEK_CUR);
 
@@ -207,14 +212,14 @@ static char plLoadWuerfel(void)
 	} else {
 		for (i=0; i<wuerfelstframes; i++)
 			framemem-=wuerfelframelens[i];
-		plWuerfel=calloc(sizeof(unsigned char), framemem);
+		plWuerfel=calloc(sizeof(uint8_t), framemem);
 		if (plWuerfel)
 			wuerfellowmem=1;
 		else {
 			free(wuerfelloadedframes);
 			wuerfelloadedframes=0;
 			wuerfellowmem=2;
-			plWuerfel=calloc(sizeof(unsigned char), maxframe);
+			plWuerfel=calloc(sizeof(uint8_t), maxframe);
 			if (!plWuerfel)
 			{
 				plCloseWuerfel();
@@ -226,11 +231,9 @@ static char plLoadWuerfel(void)
 	return 1;
 }
 
-
-
-
-static void plPrepareWuerfel()
+static void plPrepareWuerfel(void)
 {
+	int i;
 	vga13();
 /*	if(!wuerfelversion)
 	{
@@ -246,7 +249,6 @@ static void plPrepareWuerfel()
 	}
 	memset((char*)0xA0000, 0, 65536);
 	*/
-	int i;
 	for (i=16; i<256; i++)
 		gupdatepal(i, wuerfelpal[i*3-48], wuerfelpal[i*3+1-48], wuerfelpal[i*3+2-48]);
 	gflushpal();
@@ -261,13 +263,13 @@ static void plPrepareWuerfel()
 */
 }
 
-static void decodrle(unsigned char *rp, unsigned short rbuflen)
+static void decodrle(uint8_t *rp, uint16_t rbuflen)
 {
-	unsigned char *op=wuerfelframebuf;
-	unsigned char *re=rp+rbuflen;
+	uint8_t *op=wuerfelframebuf;
+	uint8_t *re=rp+rbuflen;
 	while (rp<re)
 	{
-		unsigned char c=*rp++;
+		uint8_t c=*rp++;
 		if (c<=0x0F)
 		{
 			memset(op, *rp++, c+3);
@@ -277,16 +279,16 @@ static void decodrle(unsigned char *rp, unsigned short rbuflen)
 	}
 }
 
-static void decodrledlt(unsigned char *rp, unsigned short rbuflen)
+static void decodrledlt(uint8_t *rp, uint16_t rbuflen)
 {
-	unsigned char *op=wuerfelframebuf;
-	unsigned char *re=rp+rbuflen;
+	uint8_t *op=wuerfelframebuf;
+	uint8_t *re=rp+rbuflen;
 	while (rp<re)
 	{
-		unsigned char c=*rp++;
+		uint8_t c=*rp++;
 		if (c<=0x0E)
 		{
-			unsigned char c2=*rp++;
+			uint8_t c2=*rp++;
 			if (c2!=0x0F)
 				memset(op, c2, c+3);
 			op+=c+3;
@@ -300,9 +302,9 @@ static void decodrledlt(unsigned char *rp, unsigned short rbuflen)
 
 static void wuerfelDraw(void)
 {
-	short i;
-	unsigned char *curframe;
-	unsigned short framelen;
+	int i;
+	uint8_t *curframe;
+	uint16_t framelen;
 
 	if (tmGetTimer()<(wuerfeltnext+(wuerfelversion?wuerfelcodelens[wuerfelpos]:3072)))
 		return;
@@ -387,7 +389,7 @@ static void wuerfelDraw(void)
 	plSetGraphPage(0);
 }
 
-static int wuerfelKey(unsigned short key)
+static int wuerfelKey(uint16_t key)
 {
 	switch (key)
 	{
@@ -412,7 +414,6 @@ static int wuerfelKey(unsigned short key)
 static void wuerfelSetMode(void)
 {
 	plPrepareWuerfel();
-	plScreenChanged=1;
 }
 
 static int wuerfelEvent(int ev)
@@ -429,7 +430,7 @@ static int wuerfelEvent(int ev)
 	return 1;
 }
 
-static int wuerfelIProcessKey(unsigned short key)
+static int wuerfelIProcessKey(uint16_t key)
 {
 	switch (key)
 	{
