@@ -324,7 +324,7 @@ static void drawframe(void)
 	replacebufpos+=dotbufpos-dotbuf;
 
 	n=replacebufpos-replacebuf;
-#if __BYTE_ORDER == __LITTLE_ENDIAN
+#ifndef WORDS_BIGENDIAN
 	radix(sorttemp, replacebuf, n, 3);
 	radix(replacebuf, sorttemp, n, 0);
 	radix(sorttemp, replacebuf, n, 1);
