@@ -70,6 +70,7 @@ static int plPatHeight;
 static int plPatWidth;
 static int plPatManualPat;
 static int plPatManualRow;
+#define plPatBufH (256+256)
 static uint16_t (*plPatBuf)[CONSOLE_MAX_X];
 static uint16_t pathighlight[CONSOLE_MAX_X];
 static char pattitle1[CONSOLE_MAX_X+1];
@@ -245,7 +246,6 @@ struct patviewtype
 static void preparepatgen(int pat, const struct patviewtype *pt)
 {
 	int i;
-	int plen;
 	int firstchan,chnn;
 	const char *pname;
 	int p0, n0;
@@ -262,7 +262,6 @@ static void preparepatgen(int pat, const struct patviewtype *pt)
 	patpad=(plPatWidth-maxch*pt->width-pt->gcmd*4-3)>=4;
 
 	plPrepdPat=pat;
-	plen=getpatlen(pat);
 
 	getscrollpos(maxch, &firstchan, &chnn);
 
@@ -325,6 +324,7 @@ static void preparepatgen(int pat, const struct patviewtype *pt)
 
 	firstpat=pat;
 
+	/* attempt to rewind 20 (default firsrow value) places back */
 	while (firstpat)
 	{
 		firstpat--;
@@ -336,9 +336,16 @@ static void preparepatgen(int pat, const struct patviewtype *pt)
 			break;
 		}
 	}
+	/* if we were at the start of the song, this wasn't possible, fill in with blank lines */
 	for (i=0; i<firstrow; i++)
 		writestring(plPatBuf[i], 0, COLBACK, "", CONSOLE_MAX_X);
 
+	/* firstpat = first pattern to render from
+	 * firstprow = first row to render from
+	 * firstrow = first line to render to (inside buffer)
+	 */
+
+	/* do not render past end of song */
 	while (firstpat<plPatternNum)
 	{
 		int curlen;
@@ -346,12 +353,13 @@ static void preparepatgen(int pat, const struct patviewtype *pt)
 
 		if (!(curlen=getpatlen(firstpat)))
 		{
+			/* skip zerolength patterns */
 			firstpat++;
 			continue;
 		}
 		lastprow=curlen;
-		if ((firstrow+curlen-firstprow)>(plen+60+256))
-			lastprow=plen+60+256-firstrow+firstprow;
+		if ((firstrow+curlen-firstprow)>=plPatBufH)
+			lastprow=plPatBufH-firstrow-firstprow-1;
 
 		for (i=firstprow; i<lastprow; i++)
 		{
@@ -403,11 +411,11 @@ static void preparepatgen(int pat, const struct patviewtype *pt)
 		firstprow=0;
 		firstpat++;
 
-		if (firstrow>=(plen+60))
+		if (firstrow>=plPatBufH)
 			break;
 	}
-/*	for (i=firstrow; i<(plen+60); i++)
-		writestring(plPatBuf[i], 0, COLBACK, "", CONSOLE_MAX_X);*/
+	for (i=firstrow; i<plPatBufH; i++)
+		writestring(plPatBuf[i], 0, COLBACK, "", CONSOLE_MAX_X);
 }
 
 static struct patviewtype pat6480   = {/*64,*/  3,  1, "(notes only)",                          " ",
@@ -491,8 +499,8 @@ static void gmdDrawPattern(int sel)
 	int pat=pos>>8;
 	int currow=pos&0xFF;
 	int curpat=pat;
-	int crow=currow;
-	int i,j,row;
+	signed int crow=currow;
+	signed int i,j,row;
 	int plen;
 
 	if (plPatManualPat!=-1)
@@ -554,21 +562,28 @@ static void gmdDrawPattern(int sel)
 	plen=getpatlen(pat);
 	for (i=0, row=crow-min(plPatHeight/3, 20); i<plPatHeight; i++, row++)
 	{
+		/* if no manual position, and we are not at the current position, display the buffer normal */
+		/* crow will be negativ for the lines that hit before the marker and that are from the previous pattern */
 		if ((row!=crow)&&((plPatManualPat==-1)||(row!=currow)||(pat!=curpat)))
 		{
+			/* +20, since the first 20 lines in the buffer are the lines before the marker/pattern, and that we have a bias in the row counter */
 			displaystrattr(plPatFirstLine+i, 0, plPatBuf[20+row], plPatWidth);
 			continue;
 		}
+		/* copy in the line, since it is special */
 		writestringattr(pathighlight, 0, plPatBuf[20+row], plPatWidth);
+		/* is this the current position, if so, it needs arrows */
 		if ((row==currow)&&(pat==curpat))
 		{
 			writestring(pathighlight, 2, COLMARK, "\x10", 1);
 			if (patwidth>=132)
 				writestring(pathighlight, patwidth-4, COLMARK, "\x11", 1);
 		}
+		/* if this is the target line (manual browse overrides this position, highlight it */
 		if (row==crow)
 			for (j=0; j<patwidth; j++)
 				pathighlight[j]=(pathighlight[j]|(COLHLOR<<8))&((COLHLAND<<8)|0xFF);
+		/* and print to screen */
 		displaystrattr(plPatFirstLine+i, 0, pathighlight, plPatWidth);
 	}
 }
@@ -743,7 +758,7 @@ static int trkEvent(int ev)
 			plTrackActive=cfGetProfileBool2(cfScreenSec, "screen", "pattern", 1, 1);
 			return 0;
 		case cpievInit:
-			plPatBuf=calloc(sizeof(short), (256+60+60/*don't ask where we get these from */)*CONSOLE_MAX_X);
+			plPatBuf=calloc(sizeof(short), (plPatBufH/*don't ask where we get these from */)*CONSOLE_MAX_X);
 			if (!plPatBuf)
 				return 0;
 			break;
