@@ -18,7 +18,7 @@
  *    -window position is not reseted anymore when switching from graphicsmode
  *     to textmode
 
- * cp.ini:
+ * ocp.ini:
  * [screen]
  *   volctrl80=off         ; volctrl active by default only in 132column mode,
  *   volctrl132=on         ; not in 80.
@@ -272,9 +272,9 @@ static void Draw(int focus)
 			{
 				int p4=(po<<2)/barlen;                    /* range: 0..4 */
 				if(po<p)
-					buf[po+ll+3]=((unsigned char)'')| ( (i==active && focus)? (("\x01\x09\x0b\x0f"[p4>3?3:p4])<<8):0x0800);
+					buf[po+ll+3]=((unsigned char)'\xfe')| ( (i==active && focus)? (("\x01\x09\x0b\x0f"[p4>3?3:p4])<<8):0x0800);
 				else
-					buf[po+ll+3]=((unsigned char)'')|(hc<<8);
+					buf[po+ll+3]=((unsigned char)'\xfa')|(hc<<8);
 			}
 		}
 		
@@ -324,7 +324,6 @@ static int IProcessKey(uint16_t key)
 			{
 				struct ocpvolstruct x;
 				vol[active].volreg->GetVolume(&x, vol[active].id);
-				
 				if (!x.min && x.max<0)
 				{
 					x.val++;
