@@ -10,8 +10,6 @@
  *    -changed INI reading of driver symbols to _dllinfo lookup
  */
 
-#define NO_PLRBASE_IMPORT
-
 #include "../config.h"
 #include "deviplay.h"
 #include <stdlib.h>
@@ -19,6 +17,7 @@
 #include <stdio.h>
 #include "types.h"
 #include "boot/pmain.h"
+#include "filesel/dirdb.h"
 #include "filesel/pfilesel.h"
 #include "filesel/mdb.h"
 #include "filesel/modlist.h"
@@ -70,9 +69,9 @@ static void setdevice(struct devinfonode **curdev, struct devinfonode *dev)
 		return;
 	if (dev->linkhand<0)
 	{
-		char lname[12];
+		char lname[22];
 		char *dsym;
-		strncpy(lname,cfGetProfileString(dev->handle, "link", ""),11);
+		strncpy(lname,cfGetProfileString(dev->handle, "link", ""),21);
 		dev->linkhand=lnkLink(lname);
 		if (dev->linkhand<0)
 		{
@@ -126,6 +125,8 @@ void plrResetDevice(void)
 	setdevice(&curplaydev, defplaydev);
 }
 
+static struct dmDrive *dmSETUP;
+
 static int playdevinit(void)
 {
 	const char *def;
@@ -133,7 +134,9 @@ static int playdevinit(void)
 #ifdef INITCLOSE_DEBUG
 	fprintf(stderr, "playdevinit... trying to init all sound devices [sound]->playerdevices\n");
 #endif
-	
+
+	dmSETUP=RegisterDrive("setup:");
+
 	if (!strlen(cfGetProfileString2(cfSoundSec, "sound", "playerdevices", "")))
 		return errOk;
 	fprintf(stderr, "playerdevices:\n");
@@ -174,79 +177,54 @@ static void playdevclose(void)
 	}
 }
 
-static int plrReadDir(struct modlist *ml, const char *drive, const char *path, const char *mask, unsigned long opt)
+static int plrReadDir(struct modlist *ml, const struct dmDrive *drive, const uint32_t path, const char *mask, unsigned long opt)
 {
 	struct modlistentry m;
+	uint32_t node;
 
-/*  if (opt&RD_PUTDSUBS)
-  {
-    fsConvFileName12(m.name, "@:", "");
-    m.fileref=0xFFFF;
-    m.dirref=dmGetDriveDir(0);
-    if (!mdbAppendNew(ml, m))
-      return 0;
-  }*/
-	if (strcmp(drive, "setup:"))
+	if (drive!=dmSETUP)
 		return 1;
 
+	node = dirdbFindAndRef(dmSETUP->basepath, "DEVICES");
+
 	if (opt&RD_PUTSUBS)
 	{
-		if (!strcmp(path, "/"))
-		if ((ml->find(ml, drive, "/DEVICES/"))<0)
+		if (path==dmSETUP->basepath)
 		{
-/*			m=calloc(1, sizeof(struct modlistentry));*/
-			memset(&m, 0, sizeof(m));
-
-			m.drive=drive;
-			strcpy(m.name, "DEVICES");
-			strcpy(m.shortname, "DEVICES");
-			strcpy(m.fullname, "/DEVICES/");
-			m.flags=MODLIST_FLAG_DIR;
-			ml->append(ml, &m);
+			if (ml->find(ml, node)<0)
+			{
+				memset(&m, 0, sizeof(m));
+				m.drive=drive;
+				strcpy(m.name, "DEVICES");
+				strcpy(m.shortname, "DEVICES");
+				m.dirdbfullpath=node;
+				m.flags=MODLIST_FLAG_DIR;
+				ml->append(ml, &m);
+			}
 		}
 			
 	}
 
-/*  if (opt&RD_PUTSUBS)
-  {
-    dmGetPath(path, dirref);
-    if (!strcmp(path, "@:\\"))
-    {
-      fsConvFileName12(m.name, "DEVICES", "");
-      dmGetPath(path, dirref);
-      strcat(path, "DEVICES");
-      m.dirref=dmGetPathReference(path);
-      if (m.dirref==0xFFFF)
-        return 0;
-      m.fileref=0xFFFE;
-      if (!mdbAppendNew(ml, m))
-        return 0;
-    }
-  }*/
-
-	if (!strcmp(path, "/DEVICES/"))
-
+	if (path==node)
 	{
 		struct devinfonode *dev;
 		for (dev=plPlayerDevices; dev; dev=dev->next)
 		{
 			char hnd[9];
 			strcpy(hnd, dev->handle);
-/*			strupr(hnd);*/
 			memset(&m, 0, sizeof(m));
 
 			fsConvFileName12(m.name, hnd, ".DEV");
 /*			if (fsMatchFileName12(m.name, mask))*/
 			{
+				char npath[64];	
 				m.fileref=mdbGetModuleReference(m.name, dev->dev.mem);
 				if (m.fileref==0xffffffff)
-					return 0;
+					goto out;
 				m.drive=drive;
-/*				m.dirref=dirref;*/
 				strncpy(m.shortname, m.name, 12);
-				strcpy(m.fullname, "/DEVICES/");
-				strcat(m.fullname, hnd);
-				strcat(m.fullname, ".DEV");
+				snprintf(npath, 64, "%s.DEV", hnd);
+				m.dirdbfullpath=dirdbFindAndRef(path, npath);
 				m.flags=MODLIST_FLAG_FILE|MODLIST_FLAG_VIRTUAL;
 				if (mdbGetModuleType(m.fileref)!=mtDEVp)
 				{
@@ -259,42 +237,12 @@ static int plrReadDir(struct modlist *ml, const char *drive, const char *path, c
 					mdbWriteModuleInfo(m.fileref, &mi);
 				}
 				ml->append(ml, &m);
+				dirdbUnref(m.dirdbfullpath);
 			}
 		}
 	}
-
-/*  dmGetPath(path, dirref);
-  if (!strcmp(path, "@:\\DEVICES\\"))
-  {
-    devinfonode *dev;
-    for (dev=plPlayerDevices; dev; dev=dev->next)
-    {
-      char hnd[9];
-      strcpy(hnd, dev->handle);
-      strupr(hnd);
-      fsConvFileName12(m.name, hnd, ".DEV");
-      if (fsMatchFileName12(m.name, mask))
-      {
-        m.dirref=dirref;
-        m.fileref=mdbGetModuleReference(m.name, dev->dev.mem);
-        if (m.fileref==0xFFFF)
-          return 0;
-        if (mdbGetModuleType(m.fileref)!=mtDEVp)
-        {
-          moduleinfostruct mi;
-          mdbGetModuleInfo(mi, m.fileref);
-          mi.flags1|=MDB_VIRTUAL;
-          mi.channels=dev->dev.chan;
-          strcpy(mi.modname, dev->name);
-          mi.modtype=mtDEVp;
-          mdbWriteModuleInfo(m.fileref, mi);
-        }
-        if (!mdbAppend(ml, m))
-          return 0;
-      }
-    }
-  }*/
-
+out:
+	dirdbUnref(node);
 	return 1;
 }
 
