@@ -52,18 +52,19 @@ static void sampto8(struct sampleinfo *s)
 static void samptomono(struct sampleinfo *s)
 {
 	int i;
+	int l = s->length+SAMPEND;
 	s->type&=~mcpSampStereo;
 	s->type|=mcpSampRedStereo;
 	if (s->type&mcpSampFloat)
-		for (i=0; i<(s->length+SAMPEND); i++)
+		for (i=0; i<l; i++)
 			((float *)s->ptr)[i]=(((float *)s->ptr)[2*i]+((float *)s->ptr)[2*i+1])/2;
 	else if (s->type&mcpSamp16Bit)
-		for (i=0; i<(s->length+SAMPEND); i++)
+		for (i=0; i<l; i++)
 			((int16_t *)s->ptr)[i]=(((int16_t *)s->ptr)[2*i]+((int16_t *)s->ptr)[2*i+1])>>1;
 	else
-		for (i=0; i<(s->length+SAMPEND); i++)
+		for (i=0; i<l; i++)
 			((int8_t *)s->ptr)[i]=(((int8_t *)s->ptr)[2*i]+((int8_t *)s->ptr)[2*i+1])>>1;
-	s->ptr=realloc(s->ptr,(s->length+SAMPEND)<<sampsizefac(s->type));
+	s->ptr=realloc(s->ptr,l<<sampsizefac(s->type));
 }
 
 
@@ -238,6 +239,7 @@ static int expandsmp(struct sampleinfo *s, int nopingpongloops)
 	{
 		if (sampsizefac(s->type)==2)
 		{
+			int l;
 			float *p=(float *)s->ptr+s->sloopend;
 			for (c=0; c<(s->length-s->sloopend); c++)
 				p[c+sexpandloop]=p[c];
@@ -247,8 +249,9 @@ static int expandsmp(struct sampleinfo *s, int nopingpongloops)
 			else
 				for (c=0; c<sreplen; c++)
 					p[c]=p[-1-c];
+			l=sreplen<<1;
 			for (c=sreplen; c<sexpandloop; c++)
-				p[c]=p[c-(sreplen<<1)];
+				p[c]=p[c-l];
 		} else
 			if (sampsizefac(s->type)==1)
 			{
@@ -376,13 +379,14 @@ static int repairsmp(struct sampleinfo *s)
 static void dividefrq(struct sampleinfo *s)
 {
 	int i;
+	int l=s->length>>1;
 	if (sampsizefac(s->type)==2)
-		for (i=0; i<(s->length>>1); i++)
+		for (i=0; i<l; i++)
 			((float *)s->ptr)[i]=((float *)s->ptr)[2*i];
 	else if (sampsizefac(s->type)==1)
-		for (i=0; i<(s->length>>1); i++)
+		for (i=0; i<l; i++)
 			((int16_t *)s->ptr)[i]=((int16_t *)s->ptr)[2*i];
-	else for (i=0; i<(s->length>>1); i++)
+	else for (i=0; i<l; i++)
 		((int8_t *)s->ptr)[i]=((int8_t *)s->ptr)[2*i];
 
 	s->length>>=1;
@@ -572,7 +576,7 @@ static int convertsample(struct sampleinfo *s)
 	if (s->loopstart>=s->loopend)
 		s->type&=~mcpSampLoop;
 
-#if __BYTE_ORDER == __LITTLE_ENDIAN
+#ifndef WORDS_BIGENDIAN
 	if ((s->type&(mcpSampBigEndian|mcpSamp16Bit))==(mcpSampBigEndian|mcpSamp16Bit))
 #else
 	if ((s->type&(mcpSampBigEndian|mcpSamp16Bit))==(mcpSamp16Bit))
@@ -585,7 +589,7 @@ static int convertsample(struct sampleinfo *s)
 			((char*)s->ptr)[i]=((char*)s->ptr)[i+1];
 			((char*)s->ptr)[i+1]=tmp;
 		}
-#if __BYTE_ORDER == __LITTLE_ENDIAN
+#ifndef WORDS_BIGENDIAN
 		s->type&=~mcpSampBigEndian;
 #else
 		s->type|=mcpSampBigEndian;
