@@ -19,8 +19,10 @@
 #include "cpiface/vol.h"
 #include "dev/imsdev.h"
 #include "dev/player.h"
+#include "filesel/dirdb.h"
 #include "filesel/mdb.h"
 #include "filesel/modlist.h"
+#include "filesel/pfilesel.h"
 #ifdef PLR_DEBUG
 #include "stuff/poutput.h"
 #endif
@@ -36,6 +38,7 @@ static void alsaOpenDevice(void);
 
 static int defaultcard, defaultdevice;
 
+static struct dmDrive *dmSETUP;
 
 /* stolen from devposs */
 #define MAX_ALSA_MIXER 256
@@ -319,7 +322,7 @@ static FILE *alsaSelectPcmOut(struct modlistentry *entry)
 	return NULL;
 }
 
-static int list_devices_for_card(int card, struct modlist *ml, const char *drive, const char *mask, unsigned long opt)
+static int list_devices_for_card(int card, struct modlist *ml, const struct dmDrive *drive, const uint32_t parent, const char *mask, unsigned long opt)
 {
 	char dev[64];
 	char *card_name;
@@ -416,7 +419,7 @@ static int list_devices_for_card(int card, struct modlist *ml, const char *drive
 			snprintf(entry.shortname, sizeof(entry.shortname), "hw:%d,%d.dev", card, pcm_device);
 			strcpy(entry.name, entry.shortname);
 			entry.drive=drive;
-			snprintf(entry.fullname, sizeof(entry.fullname), "/ALSA/PCM.OUT/%s", entry.name);
+			entry.dirdbfullpath=dirdbFindAndRef(parent, entry.name);
 			entry.flags=MODLIST_FLAG_FILE|MODLIST_FLAG_VIRTUAL;
 			entry.fileref=mdbGetModuleReference(entry.name, 0);
 			if (entry.fileref!=0xffffffff)
@@ -432,6 +435,7 @@ static int list_devices_for_card(int card, struct modlist *ml, const char *drive
 			entry.adb_ref=0xffffffff;
 			entry.Read=0; entry.ReadHeader=0; entry.ReadHandle=alsaSelectPcmOut;
 			ml->append(ml, &entry);
+			dirdbUnref(entry.dirdbfullpath);
 		}
 	}
 #ifdef ALSA_DEBUG
@@ -441,7 +445,7 @@ static int list_devices_for_card(int card, struct modlist *ml, const char *drive
 	return 0;
 }
 
-static int list_cards(struct modlist *ml, const char *mask, const char *drive, unsigned long opt)
+static int list_cards(struct modlist *ml, const struct dmDrive *drive, uint32_t parent, const char *mask,  unsigned long opt)
 {
 	int card=-1;
 	int result;
@@ -463,7 +467,7 @@ static int list_cards(struct modlist *ml, const char *mask, const char *drive, u
 	defaultdevice=-1;
         while (card>-1)
         {
-                list_devices_for_card(card, ml, drive, mask, opt);
+                list_devices_for_card(card, ml, drive, parent, mask, opt);
 #ifdef ALSA_DEBUG
 	fprintf(stderr, "ALSA snd_card_next(&card (%i)) = ", card);
 #endif	
@@ -971,6 +975,8 @@ static int volalsaSetVolume(struct ocpvolstruct *v, int n)
 static int alsaInit(const struct deviceinfo *c)
 {
 /*	memcpy(&currentcard, card, sizeof(struct deviceinfo));*/
+	dmSETUP=RegisterDrive("setup:");
+
 	plrSetOptions=SetOptions;
 	plrPlay=alsaPlay;
 	plrStop=alsaStop;
@@ -985,7 +991,7 @@ static int alsaInit(const struct deviceinfo *c)
 
 static int alsaDetect(struct deviceinfo *card)
 {
-	list_cards(NULL, NULL, NULL, 0);
+	list_cards(NULL, NULL, DIRDB_NOPARENT, NULL, 0);
 	card->dev=&plrAlsa;
 	card->port=defaultcard;
 	card->port2=defaultdevice;
@@ -1007,45 +1013,48 @@ static void alsaClose(void)
 
 /* driver font API stop */
 
-static int alsaReadDir(struct modlist *ml, const char *drive, const char *path, const char *mask, unsigned long opt)
+static int alsaReadDir(struct modlist *ml, const struct dmDrive *drive, const uint32_t path, const char *mask, unsigned long opt)
 {
 	struct modlistentry entry;
+	uint32_t dmalsa;
+	uint32_t dmpcmout;
+
+	if (drive!=dmSETUP)
+		return 1;
+
 	memset(&entry, 0, sizeof(entry));
 
-	if (strcmp(drive, "setup:"))
-		return 1;
-	if (!strcmp(path, "/"))
+	dmalsa=dirdbFindAndRef(dmSETUP->basepath, "ALSA");
+
+	if (path==dmSETUP->basepath)
 	{
 		strcpy(entry.shortname, "ALSA");
 		strcpy(entry.name, "ALSA");
 		entry.drive=drive;
-		strcpy(entry.fullname, "/ALSA/");
+		entry.dirdbfullpath=dmalsa;
 		entry.flags=MODLIST_FLAG_DIR;
 		entry.fileref=0xffffffff;
 		entry.adb_ref=0xffffffff;
 		entry.Read=0; entry.ReadHeader=0; entry.ReadHandle=0;
 		ml->append(ml, &entry);
-		return 1;
+	} else {
+		dmpcmout=dirdbFindAndRef(dmalsa, "PCM.OUT");
+		if (path==dmalsa)
+		{
+			strcpy(entry.shortname, "PCM.OUT");
+			strcpy(entry.name, "PCM.OUT");
+			entry.drive=drive;
+			entry.dirdbfullpath=dmpcmout;
+			entry.flags=MODLIST_FLAG_DIR;
+			entry.fileref=0xffffffff;
+			entry.adb_ref=0xffffffff;
+			entry.Read=0; entry.ReadHeader=0; entry.ReadHandle=0;
+			ml->append(ml, &entry);
+		} else if (path==dmpcmout)
+			list_cards(ml, drive, path, mask, opt);
+		dirdbUnref(dmpcmout);
 	}
-	if (!strcmp(path, "/ALSA/"))
-	{
-		strcpy(entry.shortname, "PCM.OUT");
-		strcpy(entry.name, "PCM.OUT");
-		entry.drive=drive;
-		strcpy(entry.fullname, "/ALSA/PCM.OUT/");
-		entry.flags=MODLIST_FLAG_DIR;
-		entry.fileref=0xffffffff;
-		entry.adb_ref=0xffffffff;
-		entry.Read=0; entry.ReadHeader=0; entry.ReadHandle=0;
-		ml->append(ml, &entry);
-		return 1;
-	}
-	if (!strcmp(path, "/ALSA/PCM.OUT/"))
-	{
-		list_cards(ml, drive, mask, opt);
-		return 1;
-	}
-
+	dirdbUnref(dmalsa);
 	return 1;
 }
 
