@@ -322,6 +322,8 @@ static void mixmain(/*int min*/)
 	{
 		int pass2=((bufpos+bufdeltatot)>buflen)?(bufpos+bufdeltatot-buflen):0;
 
+		fprintf(stderr, "(bit16=%d pass2=%d\n", bit16, pass2);
+
 		if (bit16)
 		{
 			memsetw((int16_t *)plrbuf+(bufpos<<stereo), signedout?0:0x8000, (bufdeltatot-pass2)<<stereo);
@@ -394,7 +396,23 @@ static void mixmain(/*int min*/)
 		/* optionally turn off the declicking */
 		if (!declick)
 			fadeleft=faderight=0;
-
+#ifdef MIXER_DEBUG
+		{
+			int i;
+			fprintf(stderr, "nsamples=%d\n", nsamples);
+			for (i=0;i<nvoices;i++)
+				if (voiceflags[i])
+				{
+					fprintf(stderr, "voice #%d\n", i);
+					fprintf(stderr, "  samp: %p (%p)\n", channels[i].samp, channels[i].sbpos);
+					fprintf(stderr, "  looplen: %08x\n", looplen[i]);
+					fprintf(stderr, "  voiceflags: 0x%08x\n", voiceflags[i]);
+					fprintf(stderr, "  freq: 0x%08x:0x%08x\n", freqw[i], freqf[i]);
+					fprintf(stderr, "  vol %d %d\n", volleft[i], volright[i]);
+				}
+			fprintf(stderr, "\n");
+		}
+#endif
 		mixer();
 
 		tickplayed+=bufdelta<<8;
@@ -798,6 +816,14 @@ static int LoadSamples(struct sampleinfo *sil, int n)
 	if (!mcpReduceSamples(sil, n, 0x40000000, mcpRedToMono|mcpRedToFloat|mcpRedNoPingPong))
 		return 0;
 
+#ifdef MIXER_DEBUG
+	{
+		int i;
+		for (i=0;i<n;i++)
+			fprintf(stderr, "sample #% 3d: %p - %p\n", i, sil[i].ptr, sil[i].ptr + sil[i].length*sizeof(float));
+	}
+#endif
+
 	samples=sil;
 	samplenum=n;
 
