@@ -26,11 +26,13 @@
 #include <unistd.h>
 #include "types.h"
 #include "adb.h"
+#include "dirdb.h"
 #include "boot/plinkman.h"
 #include "stuff/poutput.h"
 #include "boot/psetting.h"
 #include "modlist.h"
 #include "mdb.h"
+#include "pfilesel.h"
 #include "stuff/compat.h"
 
 static struct adbregstruct *adbPackers = 0;
@@ -550,10 +552,13 @@ static FILE *adb_ReadHandle(struct modlistentry *entry)
 	char temppath[PATH_MAX+1];
 	char ext[NAME_MAX+1];
 
+	char npath[PATH_MAX+1];
+
 	struct arcentry *this/*, *parent*/;
 	this=&adbData[entry->adb_ref];
 
-	_splitpath(entry->fullname, NULL, dir, NULL, NULL);
+	dirdbGetFullName(entry->dirdbfullpath, npath, 0);
+	_splitpath(npath, NULL, dir, NULL, NULL);
 
 	/* TODO, logic here should work / for / and stat for dir/file */
 	
@@ -634,21 +639,17 @@ static int adb_Read(struct modlistentry *entry, char **mem, size_t *size)
 	return 0;
 }
 
-static int arcReadDir(struct modlist *ml, const char *drive, const char *path, const char *mask, unsigned long opt)
+static int arcReadDir(struct modlist *ml, const struct dmDrive *drive, const uint32_t path, const char *mask, unsigned long opt)
 {
 	char _path[PATH_MAX+1];
 
 	struct modlistentry m;
 
-	if (strcmp(drive, "file:"))
+	if (drive!=dmFILE)
 		return 1;
-	
-	strcpy(_path, path);
-	if (_path[strlen(_path)-1]=='/')
-		_path[strlen(_path)-1]=0;
-	
+
+	dirdbGetFullName(path, _path, DIRDB_FULLNAME_NOBASE|DIRDB_FULLNAME_ENDSLASH);
 /*	fprintf(stderr, "arcReadDir drive=%s path=%s mask=%s opt=%ld\n", drive, path, mask, opt);*/
-	
 /*	dmGetPath(path, dirref);*/
       	if (isarchivepath(_path))
       	{
@@ -673,6 +674,7 @@ static int arcReadDir(struct modlist *ml, const char *drive, const char *path, c
 		{
 			char name[NAME_MAX+1];
 			char ext[NAME_MAX+1];
+			char npath[PATH_MAX+1];
 
 			char *tmp=rindex(newfilepath, '/');
 			if (!tmp)
@@ -686,7 +688,8 @@ static int arcReadDir(struct modlist *ml, const char *drive, const char *path, c
 			strcpy(m.name, newfilepath);
 
 			m.drive=drive;
-			_makepath(m.fullname, 0, _path, name, ext);
+			_makepath(npath, 0, _path, name, ext);
+			m.dirdbfullpath=dirdbResolvePathAndRef(npath);
 			if ((strlen(name)+strlen(ext))<NAME_MAX)
 				strcat(name, ext);
 			m.flags=MODLIST_FLAG_FILE|MODLIST_FLAG_VIRTUAL;
@@ -702,6 +705,7 @@ static int arcReadDir(struct modlist *ml, const char *drive, const char *path, c
 #endif
 
 			ml->append(ml, &m);
+			dirdbUnref(m.dirdbfullpath);
 		}
 		if (done==-1)
 			return 0;
