@@ -66,7 +66,8 @@ unsigned char fsHelp2(void)
 		unsigned short key;
 		brDisplayHelp();
 
-		while (!ekbhit());
+		while (!ekbhit())
+			framelock();
 		key=egetch();
 
 		plHelpKey(key);
