@@ -23,7 +23,6 @@ static int fsReadMemInfo(struct moduleinfostruct *m, const char *buf, size_t len
 	char *b=(char *)buf;
 	int pos=10;
 	int num=0;
-	char linebuf[512];
 
 	if (!memcmp(buf,"[playlist]", 10))
 	{
@@ -44,62 +43,43 @@ static int fsReadMemInfo(struct moduleinfostruct *m, const char *buf, size_t len
 		}
 		if (num)
 		{
-			sprintf(m->modname, "PLS style play list (%d entries)", num);
+			sprintf(m->modname, "PLS style playlist (%d entries)", num);
 			m->modtype=mtPLS;
+			m->flags1|=MDB_PLAYLIST;
 			return 1;
 		} else {
-			strcpy(m->modname,"PLS style play list ?");
+			strcpy(m->modname,"PLS style playlist ?");
 			m->modtype=mtPLS;
+			m->flags1|=MDB_PLAYLIST;
 			return 1;
 		}
 	}
 
  /* check for M3U-style play list */
-	pos=0;
-	num=0;
-	while (pos<len)
+	if (!memcmp(buf,"#EXTM3U", 7))
 	{
-		int pos2;
-		while (pos<len && isspace(b[pos]))
-			pos++;
-		if (pos>=len)
-			break;
-		pos2=pos;
-		while(pos2<len && b[pos2]>=32)
-			pos2++;
-		if ((pos2<len && b[pos2]!=0x0A && b[pos2]!=0x0D) || (pos2-pos)>=512)
-		{
-			num=0;
-			break;
-		}
-		if (pos2==len)
-		{
-			num=-1;
-			break;
-		}
-		memcpy(linebuf,b+pos,pos2-pos);
-		linebuf[pos2-pos]=0;
-		if (strchr(linebuf,';'))
-			*strchr(linebuf,';')=0;
-		if (*linebuf && !strchr(linebuf,'.'))
-		{
-			num=0;
-			break;
-		}
-		num++;
-		pos=pos2+1;
-	}
-	if (num>0)
-	{
-		sprintf(m->modname, "M3U style play list (%d entries)", num);
-		m->modtype=mtM3U;
-		return 1;
-	} else if (num<0)
-	{
-		strcpy(m->modname,"M3U play list ?");
+		strcpy(m->modname,"M3U playlist");
 		m->modtype=mtM3U;
+		m->flags1|=MDB_PLAYLIST;
 		return 1;
 	}
+
+	if (!strncasecmp(m->name+8, ".M3U", 4))
+	{
+		strcpy(m->modname, "Non-standard M3U playlist");
+		m->modtype=mtM3U;
+		m->flags1|=MDB_PLAYLIST;
+		return 1;
+	}
+	
+	if (!strncasecmp(m->name+8, ".PLS", 4))
+	{
+		strcpy(m->modname, "Non-standard PLS playlist");
+		m->modtype=mtPLS;
+		m->flags1|=MDB_PLAYLIST;
+		return 1;
+	}
+
 	if (!memcmp(buf, "CPArchiveCache\x1B\x00", 16))
 		strcpy(m->modname,"openCP archive data base (old)");
 	if (!memcmp(buf, "CPArchiveCache\x1B\x01", 16))
@@ -107,11 +87,10 @@ static int fsReadMemInfo(struct moduleinfostruct *m, const char *buf, size_t len
 	if (!memcmp(buf, "Cubic Player Module Information Data Base\x1B\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 60))
 		strcpy(m->modname,"openCP module info data base");
 	if (!memcmp(buf, "Cubic Player MediaLib Information Data Base\x1B\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 56))
-		strcpy(m->modname,"Cubic Player MediaLib Data Base");
+		strcpy(m->modname,"openCP medialib: data base");
 	if (!memcmp(buf, "MDZTagList\x1A\x00", 12))
 		strcpy(m->modname,"openCP MDZ file cache");
 
-	m->modtype=0xFF;
 	return 0;
 }
 
