@@ -19,6 +19,7 @@
 #include <unistd.h>
 #include "types.h"
 #include "adb.h"
+#include "dirdb.h"
 #include "gendir.h"
 #include "mdb.h"
 #include "modlist.h"
@@ -26,7 +27,7 @@
 #include "pfilesel.h"
 #include "stuff/compat.h"
 
-static int plsReadDir(struct modlist *ml, const char *drive, const char *path, const char *mask, unsigned long opt)
+static int plsReadDir(struct modlist *ml, const struct dmDrive *drive, const uint32_t path, const char *mask, unsigned long opt)
 {
 	char *s1, *s2;
 #if 0
@@ -42,20 +43,11 @@ static int plsReadDir(struct modlist *ml, const char *drive, const char *path, c
 	int fd;
 	struct stat st;
 	
-	if (strcmp(drive, "file:")) /* we, only support file:// transport for now... TODO */
-		return 1;
-	if (path[0]!='/')
+	if (drive!=dmFILE)  /* we, only support file:// transport for now... TODO */
 		return 1;
 
-	/* we need to strip of the last / */
-	strcpy(newpath, path);
-	s1=rindex(newpath, '/');
-	if (!s1)
-		return 1;
-	/* remove trailing / */
-	if (!s1[1])
-		*s1=0;
-
+	dirdbGetFullName(path, newpath, DIRDB_FULLNAME_NOBASE); /* no file: */
+	
 	/* Does the file end in .PLS ? */
 	s1=newpath+strlen(newpath)-4;
 	if (s1<newpath)
@@ -122,7 +114,7 @@ static int plsReadDir(struct modlist *ml, const char *drive, const char *path, c
 		/* skip the =, and check that the line has a length */
 		if (!*(++s2))
 			goto newline;
-		fsAddPlaylist(ml, drive, newpath, mask, opt, s2);
+		fsAddPlaylist(ml, newpath, mask, opt, s2);
 newline:
 		buftail_n-=(s1-buftail)+1;
 		buftail=s1+1;
