@@ -186,6 +186,7 @@ static int doReadVersion110Helpfile(FILE *file)
 		Page[i].lines = uint32_little (Page[i].lines);
 
 		fread(&compdatasize[i], sizeof(compdatasize[i]), 1, file);
+		compdatasize[i]=uint32_little(compdatasize[i]);
 		Page[i].links=NULL;
 		Page[i].rendered=NULL;
 	};
@@ -309,7 +310,7 @@ void brRenderPage(helppage *pg)
 {
 	link_list *lst, *endlst;
 	int        lcount;
-	char       linebuf[160];
+	uint16_t   linebuf[80];
 	char       *data;
 	char       attr;
 	int        x, y, i;
@@ -384,8 +385,7 @@ void brRenderPage(helppage *pg)
 						{
 							if ((x<80)&&(*data!=CMD_RAWCHAR))
 							{
-								linebuf[(x<<1)+0]=*data;
-								linebuf[(x<<1)+1]=0x03;
+								linebuf[x]=(*data)|0x0300;
 								x++;
 								llen++;
 							};
@@ -411,8 +411,7 @@ void brRenderPage(helppage *pg)
 					{
 						if (x<80)
 						{
-							linebuf[(x<<1)+0]=*data;
-							linebuf[(x<<1)+1]=attr;
+							linebuf[x]=(*data)|(attr<<8);
 							x++;
 						};
 
@@ -432,8 +431,7 @@ void brRenderPage(helppage *pg)
 
 					if (x<80)
 					{
-						linebuf[(x<<1)+0]=*data;
-						linebuf[(x<<1)+1]=attr;
+						linebuf[x]=(*data)|(attr<<8);
 						x++;
 					};
 
@@ -450,8 +448,7 @@ void brRenderPage(helppage *pg)
 		} else {
 			if (x<80)
 			{
-				linebuf[(x<<1)+0]=*data;
-				linebuf[(x<<1)+1]=attr;
+				linebuf[x]=(*data)|(attr<<8);
 				x++;
 			};
 
@@ -578,7 +575,7 @@ void brDisplayHelp(void)
 		for (y=2; y<plWinHeight; y++)
 			displayvoid(y+plWinFirstLine, 0, CONSOLE_MAX_X);
 	} else {
-		unsigned short _void[CONSOLE_MAX_X-80];
+		uint16_t _void[CONSOLE_MAX_X-80];
 		fillstr(_void, 0, 0, 0, CONSOLE_MAX_X-80);
 		for (y=0; y<plWinHeight; y++)
 		{
