@@ -21,6 +21,7 @@
 #include "types.h"
 #include "boot/plinkman.h"
 #include "boot/pmain.h"
+#include "filesel/dirdb.h"
 #include "filesel/modlist.h"
 #include "filesel/mdb.h"
 #include "filesel/adb.h"
@@ -34,8 +35,10 @@ struct sources_t;
 struct sources_t
 {
 	struct sources_t *next, *prev;
+	int i;
 	char name[PATH_MAX+1];
 };
+static int sourcecount=0;
 
 static struct sources_t *sources=NULL;
 
@@ -48,6 +51,8 @@ struct file_t
 static struct file_t *files;
 static uint32_t files_n, files_m;
 
+static struct dmDrive *dmMEDIALIB;
+
 static int mlDrawBox(void)
 {
 	int mlTop=plScrHeight/2-2;
@@ -124,9 +129,12 @@ static int mlScan(const char *source, int mlTop)
 	struct modlist *ml = create_modlist();
 	struct modlistentry *mle;
 	int i;
-	
+	uint32_t dirdbnode;
+
 	displaystr(mlTop+2, 5, 0x0f, source, plScrWidth-10);
-	fsReadDir(ml, "file:", source, "*", RD_PUTRSUBS/*|RD_PUTSUBS*/|(fsScanArcs?RD_ARCSCAN:0));
+	dirdbnode=dirdbResolvePathWithBaseAndRef(dmFILE->basepath, (char *)source);
+	fsReadDir(ml, dmFILE, dirdbnode, "*", RD_PUTRSUBS/*|RD_PUTSUBS*/|(fsScanArcs?RD_ARCSCAN:0));
+	dirdbUnref(dirdbnode);
 
 	if (ekbhit())
 	{
@@ -140,28 +148,37 @@ static int mlScan(const char *source, int mlTop)
 		mle=ml->get(ml, i);
 		if (mle->flags&MODLIST_FLAG_DIR)
 		{
+			char npath[PATH_MAX+1];
 			if (strcmp(mle->name, ".."))
 			if (strcmp(mle->name, "."))
 			if (strcmp(mle->name, "/"))
-				if (mlScan(mle->fullname, mlTop))
+			{
+				dirdbGetFullName(mle->dirdbfullpath, npath, DIRDB_FULLNAME_NOBASE|DIRDB_FULLNAME_ENDSLASH);
+				if (mlScan(npath, mlTop))
 					return -1;
+			}
 		} else if (mle->flags&MODLIST_FLAG_FILE)
 		{
 			int i;
+			char npath[PATH_MAX+1];
 			if (!mdbInfoRead(mle->fileref))
 				mdbScan(mle);
 			for (i=0;i<files_n;i++)
-				if (!strcmp(files[i].name, mle->fullname))
+			{
+				dirdbGetFullName(mle->dirdbfullpath, npath, DIRDB_FULLNAME_NOBASE);
+				if (!strcmp(files[i].name, npath))
 				{
 					files[i].flag=0;
 					goto skip;
 				}
+			}
 			if (files_n==files_m)
 			{
 				files_m+=50;
 				files=realloc(files, sizeof(struct file_t)*files_m);
 			}
-			strncpy(files[files_n].name, mle->fullname, sizeof(files[files_n].name));
+			dirdbGetFullName(mle->dirdbfullpath, npath, 0);
+			strncpy(files[files_n].name, npath, sizeof(files[files_n].name));
 			files[files_n].name[sizeof(files[files_n].name)-1]=0;
 			files[files_n].adb_ref=mle->adb_ref;
 			files[files_n].fileref=mle->fileref;
@@ -240,6 +257,7 @@ static void mlAddSource(const char *path)
 		source=malloc(sizeof(struct sources_t));
 		strcpy(source->name, path);
 		source->next=sources;
+		source->i=++sourcecount;
 		source->prev=NULL;
 		sources=source;
 		mlSaveSources();
@@ -356,7 +374,9 @@ static FILE *mlSourcesAdd(struct modlistentry *entry)
 					{
 						if (!strcmp(_dmDrives->drivename, "file:"))
 						{
-							mlAddSource(_dmDrives->currentpath);
+							char currentpath[PATH_MAX+1];
+							dirdbGetFullName(_dmDrives->currentpath, currentpath, DIRDB_FULLNAME_NOBASE|DIRDB_FULLNAME_ENDSLASH);
+							mlAddSource(currentpath);
 							break;
 						}
 						_dmDrives=_dmDrives->next;
@@ -429,23 +449,20 @@ static FILE *mlSourcesRemove(struct modlistentry *entry)
 	return NULL;
 }
 
-static int mlReadDir(struct modlist *ml, const char *drive, const char *path, const char *mask, unsigned long opt)
+static int mlReadDir(struct modlist *ml, const struct dmDrive *drive, const uint32_t path, const char *mask, unsigned long opt)
 {
 	struct modlistentry entry;
-	const char *cachedrive=NULL;
-	struct dmDrive *_dmDrives=dmDrives;
+	uint32_t dmsources, dmall, dmsearch, dmparent;
 
-	if (strcmp(drive, "medialib:"))
+	if (drive!=dmMEDIALIB)
 		return 1;
-	
-	while (_dmDrives)
-	{
-		if (!strcmp(_dmDrives->drivename, "file:"))
-			cachedrive=_dmDrives->drivename;
-		_dmDrives=_dmDrives->next;
-	}
 
-	if (!strcmp(path, "/"))
+	dmsources=dirdbFindAndRef(drive->basepath, "sources");
+	dmall=dirdbFindAndRef(drive->basepath, "all");
+	dmsearch=dirdbFindAndRef(drive->basepath, "search");
+	dmparent=dirdbGetParentAndRef(path);
+
+	if (path==drive->basepath)
 	{
 		if (!(opt&RD_PUTSUBS))
 			return 1;
@@ -453,30 +470,27 @@ static int mlReadDir(struct modlist *ml, const char *drive, const char *path, co
 		strcpy(entry.shortname, "sources");
 		strcpy(entry.name, "sources");
 		entry.drive=drive;
-		strcpy(entry.fullname, "/sources/");
+		entry.dirdbfullpath=dmsources;
 		entry.flags=MODLIST_FLAG_DIR;
 		entry.fileref=0xffffffff;
 		entry.adb_ref=0xffffffff;
 		entry.Read=0; entry.ReadHeader=0; entry.ReadHandle=0;
-
 		ml->append(ml, &entry);
 	
 		strcpy(entry.shortname, "all");
 		strcpy(entry.name, "all");
 		entry.drive=drive;
-		strcpy(entry.fullname, "/all/");
-	
+		entry.dirdbfullpath=dmall;
 		ml->append(ml, &entry);
 	
 		strcpy(entry.shortname, "search");
 		strcpy(entry.name, "search");
 		entry.drive=drive;
-		strcpy(entry.fullname, "/search/");
-
+		entry.dirdbfullpath=dmsearch;
 		ml->append(ml, &entry);
-		return 1;
+		goto out;
 	}
-	if (!strcmp(path, "/sources/"))
+	if (path==dmsources)
 	{
 		struct sources_t *source=sources;
 
@@ -486,22 +500,22 @@ static int mlReadDir(struct modlist *ml, const char *drive, const char *path, co
 		strcpy(entry.shortname, "add");
 		strcpy(entry.name, "add");
 		entry.drive=drive;
-		strcpy(entry.fullname, "/sources/add");
+		entry.dirdbfullpath=dirdbFindAndRef(dmsources, "add");
 		entry.flags=MODLIST_FLAG_FILE|MODLIST_FLAG_VIRTUAL;
 		entry.fileref=0xffffffff;
 		entry.adb_ref=0xffffffff;
 		entry.Read=0; entry.ReadHeader=0; entry.ReadHandle=mlSourcesAdd;
-
 		ml->append(ml, &entry);
-		
+		dirdbUnref(entry.dirdbfullpath);
+
 		entry.ReadHandle=0;
 		entry.flags=MODLIST_FLAG_DIR;
-
 		while (source)
 		{
 			char *last=rindex(source->name, '/');
 			char *prelast;
-			
+			char npath[64];
+
 			if (last!=source->name)
 			{
 				int len;
@@ -520,33 +534,37 @@ static int mlReadDir(struct modlist *ml, const char *drive, const char *path, co
 				strcpy(entry.shortname, "/");
 			strncpy(entry.name, source->name, sizeof(entry.name));
 			entry.name[sizeof(entry.name)-1]=0;
-			sprintf(entry.fullname, "/sources/%d/", (int)source); /* dirty oppland */
-
+			snprintf(npath, 64, "%d", source->i); /* dirty oppland */
+			entry.dirdbfullpath=dirdbFindAndRef(path, npath);
 			ml->append(ml, &entry);
+			dirdbUnref(entry.dirdbfullpath);
 
 			source=source->next;
 		}
-		return 1;
+		goto out;
 	}
-	if (!strncmp(path, "/sources/", 9))
+	if (dmparent==dmsources)
 	{
-		int id=atoi(path+9);
+		char npath[PATH_MAX+1];
+		int id;
+		dirdbGetname(path, npath);
+		id=atoi(npath);
 		struct sources_t *source=sources;
-		
+
 		strcpy(entry.shortname, "remove");
 		sprintf(entry.name, "%d/remove", id);
 		entry.drive=drive;
-		sprintf(entry.fullname, "/sources/%d/remove", id);
+		entry.dirdbfullpath=dirdbFindAndRef(path, "remove");
 		entry.flags=MODLIST_FLAG_FILE|MODLIST_FLAG_VIRTUAL;
 		entry.fileref=0xffffffff;
 		entry.adb_ref=0xffffffff;
 		entry.Read=0; entry.ReadHeader=0; entry.ReadHandle=mlSourcesRemove;
-
 		ml->append(ml, &entry);
+		dirdbUnref(entry.dirdbfullpath);
 		
 		while (source)
 		{
-			if (id==(int)source)
+			if (id==source->i)
 			{
 				int cachelen=strlen(source->name);
 				int i;	
@@ -559,24 +577,24 @@ static int mlReadDir(struct modlist *ml, const char *drive, const char *path, co
 						strncpy(entry.name, cachefilename, NAME_MAX);
 						entry.name[NAME_MAX]=0;
 					
-						entry.drive=cachedrive; /* file: */
-						strcpy(entry.fullname, files[i].name);
+						entry.drive=dmFILE;
+						entry.dirdbfullpath=dirdbResolvePathAndRef(files[i].name);
 						entry.flags=MODLIST_FLAG_FILE;
 						entry.fileref=files[i].fileref;
 						entry.adb_ref=files[i].adb_ref;
 						entry.Read=dosfile_Read;
 						entry.ReadHeader=dosfile_ReadHeader;
 						entry.ReadHandle=dosfile_ReadHandle;
-
 						ml->append(ml, &entry);
+						dirdbUnref(entry.dirdbfullpath);
 					}
 				break;
 			}
 			source=source->next;
 		}
-		return 1;
+		goto out;
 	}
-	if (!strcmp(path, "/all/"))
+	if (path==dmall)
 	{
 		int i;	
 		for (i=0;i<files_n;i++)
@@ -586,19 +604,20 @@ static int mlReadDir(struct modlist *ml, const char *drive, const char *path, co
 			strncpy(entry.name, cachefilename, NAME_MAX);
 			entry.name[NAME_MAX]=0;
 					
-			entry.drive=cachedrive; /* file: */
-			strcpy(entry.fullname, files[i].name);
+			entry.drive=dmFILE;
+			entry.dirdbfullpath=dirdbResolvePathAndRef(files[i].name);
 			entry.flags=MODLIST_FLAG_FILE;
 			entry.fileref=files[i].fileref;
 			entry.adb_ref=files[i].adb_ref;
 			entry.Read=dosfile_Read;
 			entry.ReadHeader=dosfile_ReadHeader;
 			entry.ReadHandle=dosfile_ReadHandle;
-
 			ml->append(ml, &entry);
+			dirdbUnref(entry.dirdbfullpath);
 		}
+		goto out;
 	}
-	if (!strcmp(path, "/search/"))
+	if (path==dmsearch)
 	{
 		int mlTop=mlDrawBox();
 		char str[NAME_MAX];
@@ -739,8 +758,8 @@ static int mlReadDir(struct modlist *ml, const char *drive, const char *path, co
 								strncpy(entry.name, cachefilename, NAME_MAX);
 								entry.name[NAME_MAX]=0;
 					
-								entry.drive=cachedrive; /* file: */
-								strcpy(entry.fullname, files[i].name);
+								entry.drive=dmFILE;
+								entry.dirdbfullpath=dirdbResolvePathAndRef(files[i].name);
 								entry.flags=MODLIST_FLAG_FILE;
 								entry.fileref=files[i].fileref;
 								entry.adb_ref=files[i].adb_ref;
@@ -748,9 +767,10 @@ static int mlReadDir(struct modlist *ml, const char *drive, const char *path, co
 								entry.ReadHeader=dosfile_ReadHeader;
 								entry.ReadHandle=dosfile_ReadHandle;
 								ml->append(ml, &entry);
+								dirdbUnref(entry.dirdbfullpath);
 							}
 						}
-						return 1;
+						goto out;
 					}
 			}
 			while ((curpos-scrolled)>=(plScrWidth-10))
@@ -759,6 +779,12 @@ static int mlReadDir(struct modlist *ml, const char *drive, const char *path, co
 				scrolled-=8;
 		}
 	}
+out:
+	dirdbUnref(dmsearch);
+	dirdbUnref(dmall);
+	dirdbUnref(dmsources);
+	if (dmparent!=DIRDB_NOPARENT)
+		dirdbUnref(dmparent);
 	return 1;
 }
 
@@ -770,7 +796,7 @@ static int mlint(void)
 	char sig[64];
 	uint32_t sources_n;
 
-	RegisterDrive("medialib:");
+	dmMEDIALIB=RegisterDrive("medialib:");
 
 	files_n=0;
 	files_m=50;
@@ -809,6 +835,7 @@ static int mlint(void)
 		read(f, s->name, sizeof(s->name));
 		s->name[sizeof(s->name)-1]=0;
 		s->next=sources;
+		s->i=++sourcecount;
 		s->prev=NULL;
 		sources=s;
 		sources_n--;
