@@ -29,8 +29,6 @@
 #include <assert.h>
 #include <errno.h>
 #include <fcntl.h>
-#include <id3tag.h>
-#include <mad.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
