@@ -24,7 +24,7 @@ static inline void putcmd(uint8_t **p, uint8_t c, uint8_t d)
 	*(*p)++=d;
 }
 
-int mpLoad669(struct gmdmodule *m, FILE *file)
+static int _mpLoad669(struct gmdmodule *m, FILE *file)
 {
 	int t;
 
@@ -367,4 +367,6 @@ int mpLoad669(struct gmdmodule *m, FILE *file)
 	return errOk;
 }
 
+struct gmdloadstruct mpLoad669 = { _mpLoad669 };
+
 struct linkinfostruct dllextinfo = {"gmdl669", "OpenCP Module Loader: *.669 (c) 1994-04 Niklas Beisert", DLLVERSION, 0};
