@@ -101,25 +101,6 @@ extern int mpReduceSamples(struct gmdmodule *m);
 extern int mpLoadSamples(struct gmdmodule *m);
 extern void mpRemoveText(struct gmdmodule *m);
 
-extern int mpLoadMOD(struct gmdmodule *, FILE *);
-extern int mpLoadMODt(struct gmdmodule *, FILE *);
-extern int mpLoadMODd(struct gmdmodule *, FILE *);
-extern int mpLoadM15(struct gmdmodule *, FILE *);
-extern int mpLoadM15t(struct gmdmodule *, FILE *);
-extern int mpLoadM31(struct gmdmodule *, FILE *);
-extern int mpLoadWOW(struct gmdmodule *, FILE *);
-extern int mpLoadMTM(struct gmdmodule *, FILE *);
-extern int mpLoadS3M(struct gmdmodule *, FILE *);
-extern int mpLoadXM (struct gmdmodule *, FILE *);
-extern int mpLoad669(struct gmdmodule *, FILE *);
-extern int mpLoadULT(struct gmdmodule *, FILE *);
-extern int mpLoadDMF(struct gmdmodule *, FILE *);
-extern int mpLoadOKT(struct gmdmodule *, FILE *);
-extern int mpLoadPTM(struct gmdmodule *, FILE *);
-extern int mpLoadAMS(struct gmdmodule *, FILE *);
-extern int mpLoadMDL(struct gmdmodule *, FILE *);
-extern int mpLoadIT (struct gmdmodule *, FILE *);
-
 extern char mpPlayModule(const struct gmdmodule *);
 extern void mpStopModule(void);
 extern void mpSetPosition(signed short pat, signed short row);
@@ -217,4 +198,8 @@ enum
 	fxPanVibrato
 };
 
+struct gmdloadstruct {
+	int (*load)(struct gmdmodule *m, FILE *file);
+};
+
 #endif
