@@ -69,7 +69,7 @@ static int mpLoadGen(struct gmdmodule *m, FILE *file, int type)
 	const char *link;
 	const char *name;
 	int hnd;
-	int (*loadfn)(struct gmdmodule *, FILE *);
+	struct gmdloadstruct *loadfn;
 	volatile uint8_t retval;
 
 	sprintf(secname, "filetype %d", type&0xff);
@@ -90,7 +90,7 @@ static int mpLoadGen(struct gmdmodule *m, FILE *file, int type)
 		return errSymMod;
 	}
 
-	*((void **)&loadfn)=_lnkGetSymbol(name);
+	loadfn=_lnkGetSymbol(name);
 	if (!loadfn)
 	{
 #ifdef LD_DEBUG
@@ -103,7 +103,7 @@ static int mpLoadGen(struct gmdmodule *m, FILE *file, int type)
 	fprintf(stderr, "Loading using %s-%s\n", link, name);
 #endif
 	memset(m->composer, 0, sizeof(m->composer));
-	retval=loadfn(m, file);
+	retval=loadfn->load(m, file);
 
 	lnkFree(hnd);
 
