@@ -106,11 +106,15 @@ int it_load(struct it_module *this, FILE *file)
 	hdr.msgoff  = uint32_little (hdr.msgoff);
 	hdr._d3     = uint32_little (hdr._d3);
 	if (hdr.sig!=0x4D504D49)
+	{
+		fprintf(stderr, "IT: Invalid header\n");
 		return errFormSig;
-
+	}
 	if ((hdr.flags&4)&&(hdr.cmwt<0x200))
+	{
+		fprintf(stderr, "IT: Too old format\n");
 		return errFormOldVer;
-
+	}
 	if (hdr.nords>MAX_ORDERS)
 	{
 		fprintf(stderr, "IT: Too many orders\n");
@@ -245,7 +249,10 @@ int it_load(struct it_module *this, FILE *file)
 		this->nord--;
 	}
 	if (!this->nord)
+	{
+		fprintf(stderr, "IT: No orders\n");
 		return errFormMiss;
+	}
 
 	for (i=0; i<this->nord; i++)
 		if (ords[i]==255)
@@ -372,7 +379,10 @@ int it_load(struct it_module *this, FILE *file)
 	}
 
 	if (!maxchan)
+	{
+		fprintf(stderr, "IT: No channels used?\n");
 		return errFormSupp;
+	}
 	this->nchan=maxchan;
 
 	this->nsampi=hdr.nsmps;
