@@ -66,7 +66,7 @@ static uint32_t datapos;
 static uint32_t newpos;
 
 /* devp pre-buffer zone */
-static uint16_t *buf16; /* here we dump out data before it goes live */
+static uint16_t *buf16 = 0; /* here we dump out data before it goes live */
 /* devp buffer zone */
 static uint32_t bufpos; /* devp write head location */
 static uint32_t buflen; /* devp buffer-size in samples */
@@ -78,7 +78,7 @@ static int reversestereo; /* boolean */
 static int donotloop=1;
 
 /* mpegIdler dumping locations */
-static uint8_t *mpegbuf;     /* the buffer */
+static uint8_t *mpegbuf = 0;     /* the buffer */
 static uint32_t mpegbuflen;  /* total buffer size */
 /*static uint32_t mpeglen;*/     /* expected wave length */
 static uint32_t mpegbufread; /* actually this is the write head */
@@ -363,9 +363,13 @@ void mpegIdle(void)
 		uint32_t towrap=imuldiv((((mpegbuflen+mpegbufread-mpegbufpos-1)%mpegbuflen)>>(1 /* we are always given stereo */ + 1 /* we are always given 16bit */)), 65536, mpegbufrate);
 		if (bufdelta>towrap)
 		{	/* will the eof hit inside the delta? */
-			quietlen=bufdelta-towrap;
 			if (eof) /* make sure we did hit eof, and just not out of data situasion due to streaming latency */
+			{
+				quietlen=bufdelta-towrap;
 				looped=1;
+			} else {
+				bufdelta=towrap;
+			}
 		}
 	}
 
@@ -716,9 +720,10 @@ void mpegIdle(void)
 unsigned char mpegOpenPlayer(FILE *mpeg, size_t offset, size_t fsize)
 {
 #define _MPEG_BUFSZ    256000   /* 2.5 s at 128 kbps; 1 s at 320 kbps */
+#if 0
 	unsigned char data[_MPEG_BUFSZ];
 	mad_timer_t timer;
-	
+#endif	
 	if (!(file=mpeg))
 		return 0;
 /*	if (fcntl(fileno(file), F_SETFD, FD_CLOEXEC))
@@ -744,6 +749,7 @@ unsigned char mpegOpenPlayer(FILE *mpeg, size_t offset, size_t fsize)
 	mad_stream_options(&stream, MAD_OPTION_IGNORECRC);
 	GuardPtr=NULL;
 
+#if 0
 	timer.seconds=0;
 	timer.fraction=0;
 
@@ -811,6 +817,9 @@ unsigned char mpegOpenPlayer(FILE *mpeg, size_t offset, size_t fsize)
 		mad_timer_add(&timer, frame.header.duration);
 	}
 	ft=timer.seconds;
+#else
+	ft=0;
+#endif
 	eof=0;
 	datapos = 0;
 	data_length=0;
@@ -862,6 +871,11 @@ unsigned char mpegOpenPlayer(FILE *mpeg, size_t offset, size_t fsize)
 	return 1;
 
 error_out:
+	if (mpegbuf)
+	{
+		free(mpegbuf);
+		mpegbuf=0;
+	}
 	mad_synth_finish(&synth);
 	mad_frame_finish(&frame);
 	mad_stream_finish(&stream);
@@ -873,8 +887,6 @@ void mpegClosePlayer(void)
 	if (active)
 	{
 		pollClose();
-		free(buf16);
-
 		plrClosePlayer();
 		
 		mad_synth_finish(&synth);
@@ -883,6 +895,16 @@ void mpegClosePlayer(void)
 
 		active=0;
 	}
+	if (buf16)
+	{
+		free(buf16);
+		buf16=0;
+	}
+	if (mpegbuf)
+	{
+		free(mpegbuf);
+		mpegbuf=0;
+	}
 }
 
 void mpegSetLoop(uint8_t s)
