@@ -29,12 +29,12 @@ static int freqtab[3][3]=
 
 static uint16_t fetch16(const char *buf)
 {
-	return buf[0]+(((unsigned)buf[1])<<8);
+	return ((unsigned char)buf[0])|(((unsigned char)buf[1])<<8);
 }
 
 static uint32_t fetch32(const char *buf)
 {
-	return buf[0]+(((unsigned)buf[1])<<8)+(((unsigned)buf[2])<<16)+(((unsigned)buf[3])<<24);
+	return ((unsigned char)buf[0])|(((unsigned char)buf[1])<<8)|(((unsigned char)buf[2])<<16)|(((unsigned char)buf[3])<<24);
 }
 
 static int ampegpReadMemInfo(struct moduleinfostruct *m, const char *buf, size_t len)
