@@ -124,15 +124,19 @@ static void oggIdler(void)
 		}
 		if (read>0x10000)
 			read=0x10000;
+#ifndef WORDS_BIGENDIAN
 		result=ov_read(&ov, (char *)oggbuf+oggbufread, read, 0, 2, 1, &current_section);
+#else
+		result=ov_read(&ov, (char *)oggbuf+oggbufread, read, 1, 2, 1, &current_section);
+#endif
 		if (result<=0) /* broken data... we can survive */
 		{
-			memsetw(oggbuf+oggbufread, (short)0x8000, read>>1);
+			memsetw(oggbuf+oggbufread, (uint16_t)0x8000, read>>1);
 			result=read;
 		} else {
-			signed short rs, ls;
+			int16_t rs, ls;
 			int samples=result>>1;
-			signed short *buffer=(signed short *)(oggbuf+oggbufread);
+			int16_t *buffer=(int16_t *)(oggbuf+oggbufread);
 
 			if (oggstereo)
 			{
@@ -679,7 +683,11 @@ unsigned char oggOpenPlayer(FILE *oggf)
 	oggbufpos=0;
 	oggbuffpos=0;
 	current_section=0;
+#ifdef WORDS_BIGENDIAN
+	if ((oggbufread=oggpos=ov_read(&ov, (char *)oggbuf, oggbuflen, 1, 2, 1, &current_section))<0)
+#else
 	if ((oggbufread=oggpos=ov_read(&ov, (char *)oggbuf, oggbuflen, 0, 2, 1, &current_section))<0)
+#endif
 		oggbufread=oggpos=0;
 
 	if (!plrOpenPlayer(&plrbuf, &buflen, plrBufSize))
@@ -694,7 +702,7 @@ unsigned char oggOpenPlayer(FILE *oggf)
 	oggSetVolume(64, 0, 64, 0);
 /*	oggSetAmplify(amplify);   TODO */
 
-	buf16=malloc(sizeof(unsigned short)*buflen*2);
+	buf16=malloc(sizeof(uint16_t)*buflen*2);
 	if (!buf16)
 	{
 		plrClosePlayer();
@@ -762,7 +770,7 @@ void oggSetVolume(unsigned char vol_, signed char bal_, signed char pan_, unsign
 	srnd=opt;
 }
 
-uint32_t oggGetPos()
+uint32_t oggGetPos(void)
 {
       	if (ogglen==oggbuflen)
 		return oggbufpos>>(oggstereo+1);
