@@ -41,7 +41,11 @@ static uint16_t modnotetab[85]=
 
 static inline uint32_t swapb2(uint16_t a)
 {
+#ifndef WORDS_BIGENDIAN
 	return ((a&0xFF)<<9)|((a&0xFF00)>>7);
+#else
+	return ((uint32_t)a)<<1;
+#endif
 }
 
 static int loadmod(struct xmodule *m, FILE *file, int chan, int sig, int opt)
