@@ -325,27 +325,27 @@ int ___peek_key(void)
 			case 'c'+512:
 				retval=KEY_ALT_C;
 				break;
-			case 'd'+512:
+/*			case 'd'+512:
 				retval=KEY_ALT_D;
-				break;
+				break;*/
 			case 'e'+512:
 				retval=KEY_ALT_E;
 				break;
-			case 'f'+512:
+/*			case 'f'+512:
 				retval=KEY_ALT_F;
-				break;
+				break;*/
 			case 'g'+512:
 				retval=KEY_ALT_G;
 				break;
-			case 'h'+512:
+/*			case 'h'+512:
 				retval=KEY_ALT_H;
-				break;
+				break;*/
 			case 'i'+512:
 				retval=KEY_ALT_I;
 				break;
-			case 'j'+512:
+/*			case 'j'+512:
 				retval=KEY_ALT_J;
-				break;
+				break;*/
 			case 'k'+512:
 				retval=KEY_ALT_K;
 				break;
@@ -355,42 +355,42 @@ int ___peek_key(void)
 			case 'm'+512:
 				retval=KEY_ALT_M;
 				break;
-			case 'n'+512:
+/*			case 'n'+512:
 				retval=KEY_ALT_N;
-				break;
-			case 'o'+512:
+				break;*/
+/*			case 'o'+512:
 				retval=KEY_ALT_O;
-				break;
+				break;*/
 			case 'p'+512:
 				retval=KEY_ALT_P;
 				break;
-			case 'q'+512:
+/*			case 'q'+512:
 				retval=KEY_ALT_Q;
-				break;
-			case 'r'+512:
+				break;*/
+/*			case 'r'+512:
 				retval=KEY_ALT_R;
-				break;
+				break;*/
 			case 's'+512:
 				retval=KEY_ALT_S;
 				break;
-			case 't'+512:
+/*			case 't'+512:
 				retval=KEY_ALT_T;
-				break;
-			case 'u'+512:
+				break;*/
+/*			case 'u'+512:
 				retval=KEY_ALT_U;
-				break;
-			case 'v'+512:
+				break;*/
+/*			case 'v'+512:
 				retval=KEY_ALT_V;
-				break;
-			case 'w'+512:
+				break;*/
+/*			case 'w'+512:
 				retval=KEY_ALT_W;
-				break;
+				break;*/
 			case 'x'+512:
 				retval=KEY_ALT_X;
 				break;
-			case 'y'+512:
+/*			case 'y'+512:
 				retval=KEY_ALT_Y;
-				break;
+				break;*/
 			case 'z'+512:
 				retval=KEY_ALT_Z;
 				break;
@@ -405,6 +405,9 @@ int ___peek_key(void)
 	} else {
 		switch (retval)
 		{
+			case 240:
+				retval=KEY_ALT_P;
+				break;
 			case 233:
 				retval=KEY_ALT_I;
 				break;
