@@ -828,13 +828,13 @@ static void displayvoid(uint16_t y, uint16_t x, uint16_t len)
 static void displaystrattr(uint16_t y, uint16_t x, const uint16_t *buf, uint16_t len)
 {
 	uint8_t *p=vgatextram+(y*plScrRowBytes+x*2);
-	uint8_t *b=(uint8_t *)buf;
-	int i;
-	for (i=0; i<len*2; i+=2)
+	while (len)
 	{
-		p[i]=b[i];
-		p[i+1]=plpalette[b[i+1]];
-       	}
+		*(p++)=(*buf)&0x0ff;
+		*(p++)=plpalette[((*buf)>>8)];
+		buf++;
+		len--;
+	}
 }
 
 static void displaystr(uint16_t y, uint16_t x, uint8_t attr, const char *str, uint16_t len)
