@@ -57,7 +57,7 @@ extern char *convnum(unsigned long num, char *buf, unsigned char radix, unsigned
 extern void writenum(uint16_t *buf, unsigned short ofs, unsigned char attr, unsigned long num, unsigned char radix, unsigned short len, char clip0/*=1*/);
 #define _writenum(buf, ofs, attr, num, radix, len) writenum(buf, ofs, attr, num, radix, len, 1)
 extern void writestring(uint16_t *buf, unsigned short ofs, unsigned char attr, const char *str, unsigned short len);
-extern void writestringattr(uint16_t *buf, unsigned short ofs, const void *str, unsigned short len);
+extern void writestringattr(uint16_t *buf, unsigned short ofs, const uint16_t *str, unsigned short len);
 extern void markstring(uint16_t *buf, unsigned short ofs, unsigned short len);
 extern void fillstr(uint16_t *buf, const unsigned short ofs, const unsigned char chr, const unsigned char attr, unsigned short len);
 
